@@ -7,6 +7,7 @@ from rest_framework import permissions
 
 
 class IsOwnerOrReadOnly(permissions.BasePermission):
+    """ Permit full access Owner or anyone to read only """
     def has_object_permission(self, request, view, obj):
         if request.method in permissions.SAFE_METHODS:
             return True
@@ -15,6 +16,7 @@ class IsOwnerOrReadOnly(permissions.BasePermission):
 
 
 class IsAuthenticatedAndCreateReadOnly(permissions.BasePermission):
+    """ Permit Creating/Reading only for authenticated users """
     def has_permission(self, request, view):
         if request.method in permissions.SAFE_METHODS:
             return True
