@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
+""" View of shiori UI """
 from django.shortcuts import render_to_response, redirect
 from django.template import RequestContext
 
 
 def index(request):
+    """ index view """
     return render_to_response('bookmark/index.html',
                               {'is_authenticated':
                                request.user.is_authenticated()},
@@ -11,6 +13,7 @@ def index(request):
 
 
 def profile(request):
+    """ profile view """
     return render_to_response('bookmark/profile.html',
                               {'is_authenticated':
                                request.user.is_authenticated()},
@@ -18,6 +21,7 @@ def profile(request):
 
 
 def add(request):
+    """ add bookmark view """
     if not request.user.is_authenticated():
         return redirect('/login/')
     return render_to_response('bookmark/edit.html',
@@ -27,6 +31,7 @@ def add(request):
 
 
 def categories(request):
+    """ bookmark categories view """
     return render_to_response('bookmark/categories.html',
                               {'is_authenticated':
                                request.user.is_authenticated()},
@@ -34,6 +39,7 @@ def categories(request):
 
 
 def category(request, category_id):
+    """ category view """
     return render_to_response('bookmark/category.html',
                               {'is_authenticated':
                                request.user.is_authenticated()},
@@ -41,6 +47,7 @@ def category(request, category_id):
 
 
 def tags(request):
+    """ bookmark tags view """
     return render_to_response('bookmark/tags.html',
                               {'is_authenticated':
                                request.user.is_authenticated()},
@@ -48,6 +55,7 @@ def tags(request):
 
 
 def tag(request, tag_id):
+    """ tag view """
     return render_to_response('bookmark/tag.html',
                               {'is_authenticated':
                                request.user.is_authenticated()},
@@ -55,6 +63,7 @@ def tag(request, tag_id):
 
 
 def bookmark(request, bookmark_id):
+    """ bookmark view """
     return render_to_response('bookmark/bookmark.html',
                               {'is_authenticated':
                                request.user.is_authenticated()},
@@ -62,6 +71,7 @@ def bookmark(request, bookmark_id):
 
 
 def feed_subscription(request):
+    """ feed subscription view """
     return render_to_response('bookmark/feed_subscription.html',
                               {'is_authenticated':
                                request.user.is_authenticated()},
@@ -69,6 +79,7 @@ def feed_subscription(request):
 
 
 def search(request):
+    """ search view """
     return render_to_response('bookmark/index.html',
                               {'is_authenticated':
                                request.user.is_authenticated()},
