@@ -103,8 +103,8 @@ STATICFILES_DIRS = (
 
 
 REST_FRAMEWORK = {
-    'DEFAULT_MODEL_SERIALIZER_CLASS': 'rest_framework.serializers.'
-    'HyperlinkedModelSerializer',
+    'DEFAULT_MODEL_SERIALIZER_CLASS': ('rest_framework.serializers.'
+                                       'HyperlinkedModelSerializer'),
     'DEFAULT_AUTHENTICATION_CLASSES': (
         'rest_framework.authentication.SessionAuthentication',
         ),
